==> custom_pages-v1.12.8.zip: custom_pages/messages/fi/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Add</strong> {templateName} item',
    '<strong>Custom</strong> Pages' => '<strong>Mukautetut</strong> Sivut',
    '<strong>Edit</strong> snippet' => '<strong>Muokkaa</strong> laatikkoja',
    'Add' => 'Lisää',
    'Add a file icon before the title' => 'Lisää ikoni ennen otsikkoa',
    'Adds plain HTML content to your site.' => 'Lisää selkeä HTML-sisältö sivustoosi.',
    'Advanced' => 'Laajennetut',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Mahdollistaa sivujen lisäämisen (markdown, iFrame tai linkit)',
    'Allows you to add content in MarkDown syntax.' => 'Voit lisätä sisältöä MarkDown-syntaksissa.',
    'Alternate text' => 'Valinnainen teksti',
    'Always' => 'Aina',
    'Always make a backup of your view files outside of your production environment!' => 'Tee varmuuskopiot katselutiedostostasi aina tuotantoympäristön ulkopuolella!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Tyhjä sallittu mallipohja mahdollistaa tämän conteinerin kaikki conteinerimallit.',
    'Back' => 'Takaisin',
    'Back to dashboard' => 'Takaisin',
    'Back to overview' => 'Takaisin',
    'Back to space' => 'Takaisin',
    'Category' => 'Kategoria',
    'Configuration' => 'Muoto',
    'Content' => 'Sisältö',
    'Css Class' => 'CSS Luokka',
    'Custom' => 'Muu',
    'Custom Pages' => 'Mukautetut Sivut',
    'Custom pages' => 'Mukautetut Sivut',
    'Dashboard' => 'Etusivu',
    'Default' => 'Tavallinen',
    'Default Content' => 'Oletus Sisältö',
    'Delete' => 'Poista',
    'Edit' => 'Muokkaa',
    'Edit Page' => 'Muokkaa Sivu',
    'Empty' => 'Tyhjä',
    'File' => 'Tiedosto',
    'General' => 'Yleinen',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Iconi',
    'Iframe' => 'iframe',
    'Insert' => 'Syötä',
    'Invalid request data!' => 'Virheelinen pyyntö!',
    'Invalid type selection' => 'Virheellinen tyypin valinta',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Navigointi',
    'On this page you can configure general settings of your custom pages.' => 'Tällä sivulla voit määrittää mukautettujen sivujen yleiset asetukset.',
    'Overview' => 'Sivut',
    'PHP' => 'PHP',
    'Pages' => 'Sivut',
    'Public' => 'Julkinen',
    'Reset' => 'Palauta',
    'Settings' => 'Asetukset',
    'Show additional file information (size)' => 'Näytä lisää tiedostotietoja (koko)',
    'Snippet' => 'Laatikko',
    'Snippets' => 'Laatikot',
    'Sort Order' => 'Lajittelujärjestys',
    'Source' => 'Lähdekoodi',
    'Space' => 'Sivu',
    'Spaces' => 'Sivut ',
    'Stream' => 'Aikajana',
    'Style' => 'Tyyli',
    'Style Class' => 'Tyyli luokka',
    'Submit' => 'Hyväksy',
    'Template' => 'Malli',
    'Templates' => 'Mallit',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Mallien avulla voit määrittää yhdistettäviä sivujakeita, joissa on sisäinen muokkaustoiminto.',
    'This container does not allow any further items!' => 'Tämä säiliö ei salli muita kohteita!',
    'Title' => 'Otsikko',
    'Top Navigation' => 'Yläpalkki',
    'Topics' => 'Aiheet',
    'Type' => 'Tyyppi',
    'Upload image' => 'Lataa kuva',
    'User Account Menu (Settings)' => 'Käyttäjätilien valikko (Asetukset)',
    'Visibility' => 'Näkyvyys',
    'Will embed the result of a given url as an iframe element.' => 'Asettaa tietyn URL-osoitteen tulos iframe-elementtinä.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Ohjaa pyyntöjä uudelleen annettuun (suhteellinen tai absoluuttinen) URL-osoitteeseen.',
    'Without adding to navigation (Direct link)' => 'Ilman lisäämistä mihinkään (Suora Linkki)',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Authors' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Invalid template selection!' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Target Url' => '',
    'Template Layout' => '',
    'Usage' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/fi/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Add</strong> {templateName} item',
    '<strong>Custom</strong> Pages' => '<strong>Mukautetut</strong> Sivut',
    '<strong>Edit</strong> snippet' => '<strong>Muokkaa</strong> laatikkoja',
    'Add' => 'Lisää',
    'Add a file icon before the title' => 'Lisää ikoni ennen otsikkoa',
    'Adds plain HTML content to your site.' => 'Lisää selkeä HTML-sisältö sivustoosi.',
    'Advanced' => 'Laajennetut',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Mahdollistaa sivujen lisäämisen (markdown, iFrame tai linkit)',
    'Allows you to add content in MarkDown syntax.' => 'Voit lisätä sisältöä MarkDown-syntaksissa.',
    'Alternate text' => 'Valinnainen teksti',
    'Always' => 'Aina',
    'Always make a backup of your view files outside of your production environment!' => 'Tee varmuuskopiot katselutiedostostasi aina tuotantoympäristön ulkopuolella!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Tyhjä sallittu mallipohja mahdollistaa tämän conteinerin kaikki conteinerimallit.',
    'Back' => 'Takaisin',
    'Back to dashboard' => 'Takaisin',
    'Back to overview' => 'Takaisin',
    'Back to space' => 'Takaisin',
    'Category' => 'Kategoria',
    'Configuration' => 'Muoto',
    'Content' => 'Sisältö',
    'Css Class' => 'CSS Luokka',
    'Custom' => 'Muu',
    'Custom Pages' => 'Mukautetut Sivut',
    'Custom pages' => 'Mukautetut Sivut',
    'Dashboard' => 'Etusivu',
    'Default' => 'Tavallinen',
    'Default Content' => 'Oletus Sisältö',
    'Delete' => 'Poista',
    'Edit' => 'Muokkaa',
    'Edit Page' => 'Muokkaa Sivu',
    'Empty' => 'Tyhjä',
    'File' => 'Tiedosto',
    'General' => 'Yleinen',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Iconi',
    'Iframe' => 'iframe',
    'Insert' => 'Syötä',
    'Invalid request data!' => 'Virheelinen pyyntö!',
    'Invalid type selection' => 'Virheellinen tyypin valinta',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Navigointi',
    'On this page you can configure general settings of your custom pages.' => 'Tällä sivulla voit määrittää mukautettujen sivujen yleiset asetukset.',
    'Overview' => 'Sivut',
    'PHP' => 'PHP',
    'Pages' => 'Sivut',
    'Public' => 'Julkinen',
    'Reset' => 'Palauta',
    'Settings' => 'Asetukset',
    'Show additional file information (size)' => 'Näytä lisää tiedostotietoja (koko)',
    'Snippet' => 'Laatikko',
    'Snippets' => 'Laatikot',
    'Sort Order' => 'Lajittelujärjestys',
    'Source' => 'Lähdekoodi',
    'Space' => 'Sivu',
    'Spaces' => 'Sivut ',
    'Stream' => 'Aikajana',
    'Style' => 'Tyyli',
    'Style Class' => 'Tyyli luokka',
    'Submit' => 'Hyväksy',
    'Template' => 'Malli',
    'Templates' => 'Mallit',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Mallien avulla voit määrittää yhdistettäviä sivujakeita, joissa on sisäinen muokkaustoiminto.',
    'This container does not allow any further items!' => 'Tämä säiliö ei salli muita kohteita!',
    'Title' => 'Otsikko',
    'Top Navigation' => 'Yläpalkki',
    'Topics' => 'Aiheet',
    'Type' => 'Tyyppi',
    'Upload image' => 'Lataa kuva',
    'User Account Menu (Settings)' => 'Käyttäjätilien valikko (Asetukset)',
    'Visibility' => 'Näkyvyys',
    'Will embed the result of a given url as an iframe element.' => 'Asettaa tietyn URL-osoitteen tulos iframe-elementtinä.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Ohjaa pyyntöjä uudelleen annettuun (suhteellinen tai absoluuttinen) URL-osoitteeseen.',
    'Without adding to navigation (Direct link)' => 'Ilman lisäämistä mihinkään (Suora Linkki)',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Invalid template selection!' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Sorting' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Target Url' => '',
    'Template Layout' => '',
    'Usage' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];
